<p align="center">
  <img width = "500" src="./figures/stella_logo.png"/>
</p>

	pip install stella

or

        git clone https://github.com/afeinstein20/stella
        cd stella
        python setup.py install


